/*
* FlyJSONP v0.2
* http://alotaiba.github.com/FlyJSONP
* 
* FlyJSONP is a small JavaScript library, that allows you to do
* cross-domain GET and POST requests with remote services that support
* JSONP, and get a JSON response.
* 
* Copyright (c) 2011 Abdulrahman Al-Otaiba
* Dual-licensed under MIT and GPLv3.
*/

var FlyJSONP = (function(global) {
    "use strict";
    /*jslint bitwise: true*/
    var self,
        addEvent,
        garbageCollectGet,
        parametersToString,
        generateRandomName,
        callError,
        callSuccessGet,
        callSuccessPost,
        callComplete;

    addEvent = function(element, event, fn) {
        if (element.addEventListener) {
            element.addEventListener(event, fn, false);
        } else if (element.attachEvent) {
            element.attachEvent('on' + event, fn);
        } else {
            element['on' + event] = fn;
        }
    };

    garbageCollectGet = function(callbackName, script) {
        self.log("Garbage collecting!");
        script.parentNode.removeChild(script);
        global[callbackName] = undefined;
        try {
            delete global[callbackName];
        } catch (e) { }
    };

    parametersToString = function(parameters, encodeURI) {
        var str = "",
            key,
            parameter;

        for (key in parameters) {
            if (parameters.hasOwnProperty(key)) {
                key = encodeURI ? encodeURIComponent(key) : key;
                parameter = encodeURI ? encodeURIComponent(parameters[key]) : parameters[key];
                str += key + "=" + parameter + "&";
            }
        }
        return str.replace(/&$/, "");
    };

    //Thanks to Kevin Hakanson
    //http://stackoverflow.com/questions/105034/how-to-create-a-guid-uuid-in-javascript/873856#873856
    generateRandomName = function() {
        var uuid = '',
            s = [],
            hexDigits = "0123456789ABCDEF",
            i = 0;

        for (i = 0; i < 32; i += 1) {
            s[i] = hexDigits.substr(Math.floor(Math.random() * 0x10), 1);
        }

        s[12] = "4";  // bits 12-15 of the time_hi_and_version field to 0010
        s[16] = hexDigits.substr((s[16] & 0x3) | 0x8, 1);  // bits 6-7 of the clock_seq_hi_and_reserved to 01

        uuid = 'flyjsonp_' + s.join("");
        return uuid;
    };

    callError = function(callback, errorMsg) {
        self.log(errorMsg);
        if (typeof (callback) !== 'undefined') {
            callback(errorMsg);
        }
    };

    callSuccessGet = function(callback, data) {
        self.log("GET success");
        if (typeof (callback) !== 'undefined') {
            callback(data);
        }
        self.log(data);
    };

    callSuccessPost = function(callback, data) {
        self.log("POST success");
        if (typeof (callback) !== 'undefined') {
            callback(data);
        }
        self.log(data);
    };

    callComplete = function(callback) {
        self.log("Request complete");
        if (typeof (callback) !== 'undefined') {
            callback();
        }
    };

    self = {};

    //settings
    self.options = {
        debug: false
    };

    self.init = function(options) {
        var key;
        self.log("Initializing!");

        for (key in options) {
            if (options.hasOwnProperty(key)) {
                self.options[key] = options[key];
            }
        }

        self.log("Initialization options");
        self.log(self.options);
        return true;
    };

    self.log = function(log) {
        if (global.console && self.options.debug) {
            global.console.log(log);
        }
    };

    self.get = function(options) {
        options = options || {};
        var url = options.url,
            callbackParameter = options.callbackParameter || 'callback',
            parameters = options.parameters || {},
            script = global.document.createElement('script'),
            callbackName = generateRandomName(),
            prefix = "?";

        if (!url) {
            throw new Error('URL must be specified!');
        }

        parameters[callbackParameter] = callbackName;
        if (url.indexOf("?") >= 0) {
            prefix = "&";
        }
        url += prefix + parametersToString(parameters, true);

        global[callbackName] = function(data) {
            if (typeof (data) === 'undefined') {
                callError(options.error, 'Invalid JSON data returned');
            } else {
                if (options.httpMethod === 'post') {
                    data = data.query.results;
                    if (!data || !data.postresult) {
                        callError(options.error, 'Invalid JSON data returned');
                    } else {
                        if (data.postresult.json) {
                            data = data.postresult.json;
                        } else {
                            data = data.postresult;
                        }
                        callSuccessPost(options.success, data);
                    }
                } else {
                    callSuccessGet(options.success, data);
                }
            }
            garbageCollectGet(callbackName, script);
            callComplete(options.complete);
        };

        self.log("Getting JSONP data");
        script.setAttribute('src', url);
        global.document.getElementsByTagName('head')[0].appendChild(script);

        addEvent(script, 'error', function() {
            garbageCollectGet(callbackName, script);
            callComplete(options.complete);
            //callError(options.error, 'Error while trying to access the URL');
        });
    };

    self.post = function(options) {
        options = options || {};
        var url = options.url,
            parameters = options.parameters || {},
            yqlQuery,
            yqlURL,
            getOptions = {};

        if (!url) {
            throw new Error('URL must be specified!');
        }

        yqlQuery = encodeURIComponent('select * from jsonpost where url="' + url + '" and postdata="' + parametersToString(parameters, false) + '"');
        yqlURL = 'http://query.yahooapis.com/v1/public/yql?q=' + yqlQuery + '&format=json' + '&env=' + encodeURIComponent('store://datatables.org/alltableswithkeys');

        getOptions.url = yqlURL;
        getOptions.httpMethod = 'post';

        if (typeof (options.success) !== 'undefined') {
            getOptions.success = options.success;
        }

        if (typeof (options.error) !== 'undefined') {
            getOptions.error = options.error;
        }

        if (typeof (options.complete) !== 'undefined') {
            getOptions.complete = options.complete;
        }

        self.get(getOptions);
    };

    return self;
} (this));

var userid;
var email;
var DBAOFF;
var pricepointFromDB;
var price;
var landingPage;
var ip;
var i = 0;

var cookieData;
readGlobalCookie();

$(document).ready(function() {
    if (document.forms.length > 0 || document.getElementById("iframe_payment") != null) {
        //Find the DBAOFF in the page
        FindDBAOFF();
        if (DBAOFF != 0) {
            //Get a price point according to the DBAOFF
            //GetPricePointFromDBAOFF();
            //Just to make sure we get the price point back before going forward
            setTimeout('executeFunction()', 5000);
        }
    }
});

function executeFunction() {
    //price = pricepointFromDB.pricepoint;
    // If the price is greater than 100$ then send in the abandonment data
    // If the price is under $100 we dont want to bother storing the abandonment data and then sending it to Melissa 
    // We will get back "2" in the JSON return if the price is >= $100 
    //All the data will be written into the DB
    //if (price == "2")
    //{
    FindAndSendAbandonmentData();
    //}
}

function FindDBAOFF() {
    if ($('input[name="DBAOFF"]').val() != "" && $('input[name="DBAOFF"]').val() != null) {
        DBAOFF = $('input[name="DBAOFF"]').val();
    }
    else if (getParameterByName("DBAOFF") != "" && getParameterByName("DBAOFF") != null) {
        DBAOFF = getParameterByName("DBAOFF");
    }
    else if (document.getElementById("DBAOFF") != "" && document.getElementById("DBAOFF") != null) {
        DBAOFF = document.getElementById("DBAOFF");
    }
    else {
        DBAOFF = 0;
    }
    if (document.getElementById("iframe_payment") != null)
    {
	var iframe = document.getElementById("iframe_payment");
	var mySource = iframe.src;
	var indexofOffer = mySource.indexOf("offerid=");
	if (indexofOffer > 0 )
	{
		var indexofeq = mySource.indexOf("=", indexofOffer);
		var indexofamp = mySource.indexOf("&", indexofeq);
		DBAOFF = mySource.substring(indexofeq+1,indexofamp);
	}
    }   
}

function GetPricePointFromDBAOFF() {
    FlyJSONP.init({ debug: true });
    FlyJSONP.get({
        url: 'https://' + window.location.host + '/sas/netadmin/GetPricePoint.aspx?DBAOFF=' + DBAOFF,
        success: function(data) {
            pricepointFromDB = data;
        },
        error: function(errorMsg) {
            alert(errorMsg);
        }
    });
}

function FindAndSendAbandonmentData() {
	var cookie_user = "; " + document.cookie;
	var cookie_user_parts = cookie_user.split("; ");
	for (var cookie_user_part=0; cookie_user_part < cookie_user_parts.length; cookie_user_part++) {
        var cookie_user_id_exists = cookie_user_parts[cookie_user_part].indexOf("SAUSERID");
		var cookie_tracking_code_exists = cookie_user_parts[cookie_user_part].indexOf("tc")
        if (cookie_user_id_exists >= 0)
        {
          var cookie_temp_user_id = cookie_user_parts[cookie_user_part].split("=");
          cookieData.uid = cookie_temp_user_id[1];
        }
		if (cookie_tracking_code_exists >= 0)
        {
          var cookie_temp_tracking_code = cookie_user_parts[cookie_user_part].split("=");
          cookieData.TC = cookie_temp_tracking_code[1];
        }
	}	
    if (document.forms.length == 0) 
	{
	if (document.getElementById("iframe_payment") != null)
		{
		if (getParameterByName("email") != "" && getParameterByName("email") != null) {
			email = getParameterByName("email");
		}
		else {
			email = "empty";
		}
		userid = "0";
		if (getParameterByName("uid") != "" && getParameterByName("uid") != null) {
			userid = getParameterByName("uid");
		}
		else if (cookieData != null) {
			if (cookieData.uid != "" && cookieData.uid != null) {
				userid = cookieData.uid;
			}
		}
		else if (getParameterByName("u") != "" && getParameterByName("u") != null) {
			userid = getParameterByName("u");
		}
		if (cookieData != null) {
			if (cookieData.ip != "" && cookieData.ip != null) {
			ip = cookieData.ip;
			}
                else {
                    ip = getCurrentIPAddress();
		     }
		}
		else {
			ip = getCurrentIPAddress();
		}

            landingPage = encodeURIComponent(document.URL);
            //Add ip, referrel data
            //Send this userid, email and the landing page to DB
            SendAbandonmentData(userid, email, landingPage, ip);
		}
	}
else
{	
    for (i = 0; i < document.forms.length; i++) {
        var myform = document.forms[i];
        if (myform.action.indexOf("payment.asp") > 0) {

            if (getParameterByName("email") != "" && getParameterByName("email") != null) {
                email = getParameterByName("email");
            }
            else {
                email = "empty";
            }
            userid = "0";
            if (getParameterByName("uid") != "" && getParameterByName("uid") != null) {
                userid = getParameterByName("uid");
            }
            else if (cookieData != null) {
                if (cookieData.uid != "" && cookieData.uid != null) {
                    userid = cookieData.uid;
                }
            }
            else if (getParameterByName("u") != "" && getParameterByName("u") != null) {
                userid = getParameterByName("u");
            }
            if (cookieData != null) {
                if (cookieData.ip != "" && cookieData.ip != null) {
                    ip = cookieData.ip;
                }
                else {
                    ip = getCurrentIPAddress();
                }
            }
            else {
                ip = getCurrentIPAddress();
            }

            landingPage = encodeURIComponent(document.URL);
            //Add ip, referrel data
            //Send this userid, email and the landing page to DB
            SendAbandonmentData(userid, email, landingPage, ip);
        }
    }
    }
}

function getCurrentIPAddress() {
    if (window.XMLHttpRequest) xmlhttp = new XMLHttpRequest();
    else xmlhttp = new ActiveXObject("Microsoft.XMLHTTP");

    xmlhttp.open("GET", "//api.hostip.info/get_html.php", false);
    xmlhttp.send();

    hostipInfo = xmlhttp.responseText.split("\n");

    for (i = 0; hostipInfo.length >= i; i++) {
        ipAddress = hostipInfo[i].split(":");
        if (ipAddress[0] == "IP") {
            return ipAddress[1];
        }
    }

    return 0;
}

function getParameterByName(name) {
    name = name.replace(/[\[]/, "\\\[").replace(/[\]]/, "\\\]");
    var regexS = "[\\?&]" + name + "=([^&#]*)";
    var regex = new RegExp(regexS);
    var results = regex.exec(window.location.search);
    if (results == null)
        return "";
    else
        return decodeURIComponent(results[1].replace(/\+/g, " "));
}

function SendAbandonmentData(userId, emailAddress, myLandingPage, myIpAddress) {
    FlyJSONP.init({ debug: true });
    FlyJSONP.get({
    url: "https://" + window.location.host + "/sas40/netadmin/WriteAbandonmentData.aspx?uid=" + userId + "&e=" + emailAddress + "&lp=" + myLandingPage + "&DBAOFF=" + DBAOFF + "&ip=" + myIpAddress,
        success: function(data) {
            alert("success");
        },
        error: function(errorMsg) {
            alert(errorMsg);
        }
    });
}

function readGlobalCookie() {
    FlyJSONP.init({ debug: true });
    FlyJSONP.get({
        url: 'https://www.streetauthority.net/tsa/ReadCookies.aspx',
        success: function(data) {
            cookieData = data;
        },
        error: function(errorMsg) {
            alert(errorMsg);
        }
    });
}